mailr6657 - /branches/rdc_analysis/generic_fns/structure/internal.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 04, 2008 - 14:37:
Author: bugman
Date: Fri Jul  4 14:24:00 2008
New Revision: 6657

URL: http://svn.gna.org/viewcvs/relax?rev=6657&view=rev
Log:
Bug fix for the internal PDB reader, the HETATM records are now recognised.


Modified:
    branches/rdc_analysis/generic_fns/structure/internal.py

Modified: branches/rdc_analysis/generic_fns/structure/internal.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/rdc_analysis/generic_fns/structure/internal.py?rev=6657&r1=6656&r2=6657&view=diff
==============================================================================
--- branches/rdc_analysis/generic_fns/structure/internal.py (original)
+++ branches/rdc_analysis/generic_fns/structure/internal.py Fri Jul  4 
14:24:00 2008
@@ -155,8 +155,8 @@
             if search('^MODEL', lines[i]):
                 model = int(split(lines[i])[1])
 
-            # Skip all records prior to the first ATOM record.
-            if not search('^ATOM', lines[i]) and not len(records):
+            # Skip all records prior to the first ATOM or HETATM record.
+            if not (search('^ATOM', lines[i]) or search('^HETATM', 
lines[i])) and not len(records):
                 continue
 
             # End of the model.




Related Messages


Powered by MHonArc, Updated Fri Jul 04 14:40:16 2008